#
# spec file for package python-dask-expr
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define psuffix %{nil}
%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
Name:           python-dask-expr%{psuffix}
Version:        1.1.20
Release:        1.3
Summary:        High Level Expressions for Dask
License:        BSD-3-Clause
URL:            https://github.com/dask/dask-expr
Source0:        https://github.com/dask/dask-expr/archive/refs/tags/v%{version}.tar.gz#/dask_expr-%{version}-gh.tar.gz
# PATCH-FIX-UPSTREAM dask-expr-pr1173-blockwise.patch gh#dask/dask-expr#1173
Patch0:         https://github.com/dask/dask-expr/pull/1173.patch#/dask-expr-pr1173-blockwise.patch
BuildRequires:  %{python_module base >= 3.10}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools >= 62.6}
BuildRequires:  %{python_module versioneer-toml}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-dask = 2024.12.0
Requires:       python-pandas >= 2
Requires:       python-pyarrow >= 14.0.1
Provides:       python-dask_expr = %{version}-%{release}
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module dask-dataframe}
BuildRequires:  %{python_module dask-expr = %{version}}
BuildRequires:  %{python_module distributed}
BuildRequires:  %{python_module pandas >= 2}
BuildRequires:  %{python_module pyarrow >= 14.0.1}
BuildRequires:  %{python_module pytest}
%endif
%python_subpackages

%description
Dask DataFrames with query optimization.
This is a rewrite of Dask DataFrame that includes query optimization
and generally improved organization.

%prep
%autosetup -p1 -n dask-expr-%{version}
sed -i 's/--color=yes//' pyproject.toml

%if !%{with test}
%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
%check
# https://github.com/dask/dask-expr/issues/789 (?)
donttest="test_groupby_index_array"
# wrong types expected
if [ $(getconf LONG_BIT) -eq 32 ]; then
  donttest="$donttest or test_memory_usage"
  donttest="$donttest or test_repartition_partition_size"
  donttest="$donttest or test_scalar_repr"
  donttest="$donttest or test_timeseries_gaph_size"
  donttest="$donttest or test_join_gives_proper_divisions"
fi
%pytest -k "not ($donttest)"
%endif

%if !%{with test}
%files %{python_files}
%{python_sitelib}/dask_expr
%{python_sitelib}/dask_expr-%{version}.dist-info
%endif

%changelog
* Thu Dec  5 2024 Ben Greiner <code@bnavigator.de>
- Update to 1.1.20
  * Fix value_counts with split_out != 1 (#1170) Patrick Hoefler
  * Remove recursion in task spec (#1158) Florian Jetter
  * Deprecated and remove from_legacy_dataframe usage (#1168)
    Patrick Hoefler
  * Remove from_dask_dataframe (#1167) Patrick Hoefler
  * Avoid exponentially growing graph for Assign-Projection
    combinations (#1164) Patrick Hoefler
  * Introduce more caching when walking the expression (#1165)
    Patrick Hoefler
  * Use Taskspec fuse implementation (#1162) Florian Jetter
  * Fix orphaned dependencies in Fused expression (#1163) Patrick
    Hoefler
- Add dask-expr-pr1173-blockwise.patch
  * Use new blockwise unpack collection in array
  * gh#dask/dask-expr#1173
* Fri Nov 22 2024 Dirk Müller <dmueller@suse.com>
- reenable python313, numba is available
* Wed Nov 20 2024 Benjamin Greiner <code@bnavigator.de>
- Disable python313: no numba, no dask
* Tue Nov 19 2024 Dirk Müller <dmueller@suse.com>
- update to 1.1.19:
  * rebuild for dask 2024.11.2
* Tue Nov 12 2024 Dirk Müller <dmueller@suse.com>
- update to 1.1.18:
  * Add support for Python 3.13
  * Migrate Blockwise to use taskspec
  * Migrate shuffle and merge to `P2PBarrierTask`
  * Improve Aggregation docstring explicitly mentionning
    SeriesGroupBy
  * Migrate P2P shuffle and merge to TaskSpec
  * Internal cleanup of P2P code
  * Fix meta calculation for to_datetime
  * Fix ``Merge`` divisions after filtering partitions
* Thu Oct 10 2024 Dirk Müller <dmueller@suse.com>
- update to 1.1.15:
  * Add concatenate flag to .compute()
  * Import from tokenize
* Sun Sep  8 2024 Ben Greiner <code@bnavigator.de>
- Update to 1.1.13
  * Use task-based rechunking as default (#1131) Hendrik Makait
  * Improve performance of DelayedsExpr through caching (#1132)
    Hendrik Makait
- Release 1.1.12
  * Fix concat axis 1 bug in divisions (#1128) Patrick Hoefler
  * Bump pyarrow>=14.0.1 minimum versions (#1127) James
    Bourbeau
  * Fix scalar detection of columns coming from sql (#1125)
    Patrick Hoefler
* Fri Aug 30 2024 Ben Greiner <code@bnavigator.de>
- Skip some tests on 32-bit
* Thu Aug 29 2024 Ben Greiner <code@bnavigator.de>
- Update to 1.1.11
  * Make split_out for categorical default smarter #1124 Patrick
    Hoefler
  * Avoid calling `array`` attribute on ``cudf.Series`` #1122
    `Richard (Rick) Zamora
  * Introduce ToBackend` expression #1115 `Richard (Rick) Zamora
  * Fix result index of merge #1121 Patrick Hoefler
  * Fix projection for Index class in read_parquet #1120 Patrick
    Hoefler
  * Register read_parquet` and `read_csv` as "dispatchable" #1114
    `Richard (Rick) Zamora
  * Fix merging when index name in meta missmatches actual name
    [#1119] Patrick Hoefler
  * Fix tuples as on argument in merge #1117 Patrick Hoefler
  * Drop support for Python 3.9 #1109 Patrick Hoefler
- Release 1.1.10
  * Fixup remaining upstream failures #1111 Patrick Hoefler
  * Fix some things for pandas 3 #1110 Patrick Hoefler
- Release 1.1.9
  * Patch release for Dask 2024.7.0
- Release 1.1.8
  * Fix shuffle blowing up the task graph #1108 Patrick Hoefler
  * Link fix in readme #1107 Ben
  * Fix from_pandas with chunksize and empty df #1106 Patrick
    Hoefler
  * Fix deepcopying FromPandas class #1105 Patrick Hoefler
  * Skip test if optional xarray cannot be imported #1104 Sandro
- Release 1.1.7
  * Patch release for Dask 2024.7.0
* Mon Jul  8 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.1.6:
  * Patch release for Dask 2024.6.2
  * Fix resample divisions propagation
  * Fix categorize if columns are dropped
  * Fix projection to empty from_pandas
  * Fix meta for string accessors
  * Use is_categorical_dtype dispatch for sort_values
  * Fix read_csv with positional usecols
  * Fix isin for head computation
  * Fix isin with strings
  * Use ensure_deterministic kwarg instead of config
  * Add cache argument to lower_once
  * Fix non-integer divisions in FusedIO
  * Fix dropna before merge
  * Fix sort_values for unordered categories
  * Fix to_parquet in append mode
  * reduce pickle size of parquet fragments
  * Generalize get_dummies
  * Add support for DataFrame.melt
  * Fix default name conversion in ToFrame
  * Optimize when from-delayed is called
  * Fix delayed in fusing with multipled dependencies
  * Fix None min/max statistics and missing statistics generally
  * Fix xarray integration with scalar columns
  * Fix shape returning integer
  * Fix bug in Series reductions
* Mon Apr 29 2024 Ben Greiner <code@bnavigator.de>
- Remove extra source file
* Fri Apr 26 2024 Ben Greiner <code@bnavigator.de>
- Initial specfile for v1.0.13
- Required by and versions must by in sync with dask
